@@ -3,17 +3,17 @@
  * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
  * Copyright 2007-2008 Pierre-Benoit Besse <besse@gmail.com>
  * Copyright 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -40,22 +40,22 @@
 Game::Game(PlayerSettings* playerSettings)
 {
     m_playerSettings = playerSettings;
-    
+
     // Initialize the sound state
     setSoundsEnabled(Settings::sounds());
     m_wilhelmScream = Settings::useWilhelmScream();
-    
-    m_soundPutBomb = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("sounds/putbomb.wav")));
-    m_soundExplode = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("sounds/explode.wav")));
-    m_soundBonus = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("sounds/wow.wav")));
-    m_soundFalling = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("sounds/deepfall.wav")));
-    m_soundDie = new KgSound(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("sounds/die.wav")));
-    
-    m_arena = 0;
+
+    m_soundPutBomb = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/putbomb.wav")));
+    m_soundExplode = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/explode.wav")));
+    m_soundBonus = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/wow.wav")));
+    m_soundFalling = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/deepfall.wav")));
+    m_soundDie = new KgSound(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds/die.wav")));
+
+    m_arena = nullptr;
     m_randomArenaModeArenaList.clear();
-    m_gameScene = 0;
+    m_gameScene = nullptr;
     m_winPoints = Settings::self()->pointsToWin();
-    
+
     QStringList strPlayerIDs = m_playerSettings->playerIDs();
     for(int i = 0; i < strPlayerIDs.count(); i++)
     {
@@ -68,25 +68,25 @@ Game::Game(PlayerSettings* playerSettings)
             connect(player, &Player::resurrectBonusTaken, this, &Game::resurrectBonusTaken);
         }
     }
-    
+
     init();
-    
-    for (int i = 0; i < m_players.size(); i++)
+
+    for (auto & player : m_players)
     {
-        connect(m_players[i], SIGNAL(bombDropped(Player*,qreal,qreal,bool,int)), this, SLOT(createBomb(Player*,qreal,qreal,bool,int)));
+        connect(player, SIGNAL(bombDropped(Player*,qreal,qreal,bool,int)), this, SLOT(createBomb(Player*,qreal,qreal,bool,int)));
     }
-    
+
     m_gameOver = false;
 }
 
 void Game::init()
-{    
+{
     // Create the Arena instance
     m_arena = new Arena();
 
     m_remainingTime = Settings::roundTime();
     m_bombCount = 0;
-    
+
     // Create the parser that will parse the XML file in order to initialize the Arena instance
     // This also creates all the characters
     MapParser mapParser(m_arena);
@@ -96,28 +96,24 @@ void Game::init()
     {
         if(m_randomArenaModeArenaList.isEmpty())
         {
-            m_randomArenaModeArenaList = Settings::self()->randomArenaModeArenaList();
+            auto randomArenaModeArenaList = Settings::self()->randomArenaModeArenaList();
 
             QStringList arenasAvailable;
-            const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("arenas"), QStandardPaths::LocateDirectory);
-            Q_FOREACH (const QString& dir, dirs) {
-            const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
-                Q_FOREACH (const QString& file, fileNames) {
+            const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("arenas"), QStandardPaths::LocateDirectory);
+            for(const auto& dir: dirs) {
+                const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+                for(const auto& file: fileNames) {
                     arenasAvailable.append(dir + QLatin1Char('/') + file);
                 }
             }
 
-
-            QStringList::Iterator i = m_randomArenaModeArenaList.begin();
-            while(i != m_randomArenaModeArenaList.end())
-            {
-                if(arenasAvailable.contains(*i))
-                {
-                    i++;
-                }
-                else
-                {
-                    i = m_randomArenaModeArenaList.erase(i);
+            // store the random arenas if they are available
+            for(const auto& randomArena: randomArenaModeArenaList) {
+                for(const auto& arena: arenasAvailable) {
+                    if(arena.endsWith(randomArena)) {
+                        m_randomArenaModeArenaList.append(arena);
+                        break;
+                    }
                 }
             }
 
@@ -126,8 +122,8 @@ void Game::init()
                 m_randomArenaModeArenaList = arenasAvailable;
             }
         }
-        
-        int nIndex = ((double) qrand() / RAND_MAX) * m_randomArenaModeArenaList.count();
+
+        int nIndex = (static_cast<double>(qrand()) / RAND_MAX) * m_randomArenaModeArenaList.count();
         if(nIndex < 0)
         {
             nIndex = 0;
@@ -141,32 +137,31 @@ void Game::init()
     }
     else
     {
-        filePath = QStandardPaths::locate(QStandardPaths::DataLocation, Settings::self()->arena());
+        filePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, Settings::self()->arena());
     }
-    
+
     if(!QFile::exists(filePath))
     {
         Settings::self()->useDefaults(true);
-        filePath = QStandardPaths::locate(QStandardPaths::DataLocation, Settings::self()->arena());
+        filePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, Settings::self()->arena());
         Settings::self()->useDefaults(false);
     }
-    
+
     KConfig arenaConfig(filePath, KConfig::SimpleConfig);
     KConfigGroup group = arenaConfig.group("Arena");
     QString arenaFileName = group.readEntry("FileName");
-    
-    QFile arenaXmlFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("arenas/%1").arg(arenaFileName)));
-    //QFile arenaXmlFile(QStandardPaths::locate(QStandardPaths::DataLocation, "arenas/granatier.xml"));
+
+    QFile arenaXmlFile(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("arenas/%1").arg(arenaFileName)));
     QXmlInputSource source(&arenaXmlFile);
     // Create the XML file reader
     QXmlSimpleReader reader;
     reader.setContentHandler(&mapParser);
     // Parse the XML file
     reader.parse(source);
-    
+
     QString arenaName = group.readEntry("Name");
     m_arena->setName(arenaName);
-    
+
     //create the block items
     for (int i = 0; i < m_arena->getNbRows(); ++i)
     {
@@ -180,23 +175,23 @@ void Game::init()
             }
         }
     }
-    
+
     // Start the Game timer
     m_timer = new QTimer(this);
     m_timer->setInterval(int(1000 / Granatier::FPS));
     connect(m_timer, &QTimer::timeout, this, &Game::update);
     m_timer->start();
     m_state = RUNNING;
-    
+
     m_roundTimer  = new QTimer(this);
     m_roundTimer->setInterval(1000);
     connect(m_roundTimer, &QTimer::timeout, this, &Game::decrementRemainingRoundTime);
     m_roundTimer->start();
-    
+
     m_setRoundFinishedTimer  = new QTimer(this);
     m_setRoundFinishedTimer->setSingleShot(true);
     connect(m_setRoundFinishedTimer, &QTimer::timeout, this, &Game::setRoundFinished);
-    
+
     // Init the characters coordinates on the Arena
     for (int i = 0; i < m_players.size(); i++)
     {
@@ -205,7 +200,7 @@ void Game::init()
         m_players[i]->setInitialCoordinates(qreal(Granatier::CellSize * playerPosition.x()), qreal(Granatier::CellSize * playerPosition.y()));
     }
     initCharactersPosition();
-    
+
     // Create the hidden Bonuses
     createBonus();
 }
@@ -214,12 +209,12 @@ Game::~Game()
 {
     //pause is needed to stop all animations and therefore the access of the *items to their model
     pause(true);
-    
+
     qDeleteAll(m_players);
     m_players.clear();
-    
+
     cleanUp();
-    
+
     delete m_soundPutBomb;
     delete m_soundExplode;
     delete m_soundBonus;
@@ -236,13 +231,13 @@ void Game::cleanUp()
     qDeleteAll(m_bombs);
     m_bombs.clear();
     delete m_arena;
-    m_arena = 0;
+    m_arena = nullptr;
     delete m_timer;
-    m_timer = 0;
+    m_timer = nullptr;
     delete m_roundTimer;
-    m_roundTimer = 0;
+    m_roundTimer = nullptr;
     delete m_setRoundFinishedTimer;
-    m_setRoundFinishedTimer = 0;
+    m_setRoundFinishedTimer = nullptr;
 }
 
 void Game::setGameScene(GameScene* p_gameScene)
@@ -293,7 +288,7 @@ void Game::switchPause()
     }
 }
 
-QList<Player*> Game::getPlayers() const 
+QList<Player*> Game::getPlayers() const
 {
     return m_players;
 }
@@ -330,7 +325,7 @@ QString Game::getWinner() const
 
 int Game::getWinPoints() const
 {
-    return m_winPoints; 
+    return m_winPoints;
 }
 
 QList<Bonus*> Game::getBonus() const
@@ -348,13 +343,13 @@ void Game::createBonus()
     Granatier::Bonus::Type bonusType;
     int nFullSize = m_blocks.size();
     int nQuarterSize = 0;
-    
+
     for(int nQuarter = 0; nQuarter < 4; nQuarter++)
     {
         nQuarterSize = (nQuarter < 3 ? nFullSize / 4 : nFullSize - 3 * (nFullSize / 4));
         bonusTypeList.clear();
-        
-        for (int i = 0; i < nQuarterSize; i++)
+
+        for (int i = 0; i < nQuarterSize; ++i)
         {
             if(i < nBonusCount)
             {
@@ -400,12 +395,12 @@ void Game::createBonus()
             else {
                 bonusType = Granatier::Bonus::NONE;
             }
-            
+
             bonusTypeList.append(bonusType);
         }
-        
+
         int nShuffle;
-        for (int i = 0; i < nQuarterSize; i++)
+        for (int i = 0; i < nQuarterSize; ++i)
         {
             nShuffle = nQuarterSize * (qrand()/1.0)/RAND_MAX;
             if(nShuffle >= nQuarterSize)
@@ -418,7 +413,7 @@ void Game::createBonus()
             }
             bonusTypeList.swap(i, nShuffle);
         }
-        
+
         for (int i = 0; i < nQuarterSize; ++i)
         {
             if(bonusTypeList[i] != Granatier::Bonus::NONE)
@@ -459,10 +454,10 @@ void Game::initCharactersPosition()
         m_roundTimer->stop();
         m_state = RUNNING;
         // Initialize the Player coordinates
-        for(int i = 0; i < m_players.size(); i++)
+        for(auto & player : m_players)
         {
-            m_players[i]->initCoordinate();
-            m_players[i]->init();
+            player->initCoordinate();
+            player->init();
         }
     }
 }
@@ -473,7 +468,7 @@ void Game::keyPressEvent(QKeyEvent* p_event)
     {
         return;
     }
-    
+
     // At the beginning or when paused, we start the timer when a key is pressed
     if (!m_timer->isActive())
     {
@@ -505,9 +500,9 @@ void Game::keyPressEvent(QKeyEvent* p_event)
                     cleanUp();
                     init();
                     m_gameScene->init();
-                    for(int i = 0; i < m_players.length(); i++)
+                    for(auto & player : m_players)
                     {
-                        m_players[i]->resurrect();
+                        player->resurrect();
                     }
                 }
             }
@@ -524,11 +519,11 @@ void Game::keyPressEvent(QKeyEvent* p_event)
         default:
             break;
     }
-    
+
     //TODO: make signal
-    for(int i = 0; i < m_players.size(); i++)
+    for(auto & player : m_players)
     {
-        m_players[i]->keyPressed(p_event);
+        player->keyPressed(p_event);
     }
 }
 
@@ -539,25 +534,25 @@ void Game::keyReleaseEvent(QKeyEvent* p_event)
         return;
     }
     //TODO: make signal
-    for(int i = 0; i < m_players.size(); i++)
+    for(auto & player : m_players)
     {
-        m_players[i]->keyReleased(p_event);
+        player->keyReleased(p_event);
     }
 }
 
 void Game::update()
 {
     //update Bombs
-    for (int i = 0; i < m_bombs.size(); ++i)
+    for (auto & bomb : m_bombs)
     {
-        m_bombs[i]->updateMove();
+        bomb->updateMove();
     }
-    
+
     //update Player
-    for(int i = 0; i < m_players.size(); i++)
+    for(auto & player : m_players)
     {
-        m_players[i]->updateMove();
-        m_players[i]->emitGameUpdated();
+        player->updateMove();
+        player->emitGameUpdated();
     }
 }
 
@@ -582,13 +577,13 @@ void Game::decrementRemainingRoundTime()
                 nRow = m_arena->getNbRows() * (qrand()/1.0)/RAND_MAX;
                 nCol = m_arena->getNbColumns() * (qrand()/1.0)/RAND_MAX;
                 cellType = m_arena->getCell(nRow, nCol).getType();
-                if(cellType != Granatier::Cell::WALL && cellType != Granatier::Cell::HOLE && m_arena->getCell(nRow, nCol).isWalkable(0))
+                if(cellType != Granatier::Cell::WALL && cellType != Granatier::Cell::HOLE && m_arena->getCell(nRow, nCol).isWalkable(nullptr))
                 {
                     bFound = true;
                 }
             }
             while (!bFound);
-            
+
             m_bombCount++;
             Bomb* bomb = new Bomb((nCol + 0.5) * Granatier::CellSize, (nRow + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 1000);    // time in ms
             bomb->setBombPower((qrand()/1.0)/RAND_MAX * 2 + 1);
@@ -621,14 +616,14 @@ void Game::playerDeath()
     {
         m_soundDie->start();
     }
-    
+
     //check if at most one player is alive if not already finished
     if(!m_setRoundFinishedTimer->isActive())
     {
         int nPlayerAlive = 0;
-        for(int i = 0; i < m_players.length(); i++)
+        for(auto & player : m_players)
         {
-            if(m_players[i]->isAlive())
+            if(player->isAlive())
             {
                 nPlayerAlive++;
             }
@@ -643,11 +638,11 @@ void Game::playerDeath()
 
 void Game::resurrectBonusTaken()
 {
-    for(int i = 0; i < m_players.length(); i++)
+    for(auto & player : m_players)
     {
-        if(!(m_players[i]->isAlive()))
+        if(!(player->isAlive()))
         {
-            m_players[i]->resurrect();
+            player->resurrect();
         }
     }
 }
@@ -660,7 +655,7 @@ void Game::setRoundFinished()
     {
         return;
     }
-    for(int i = 0; i < m_players.length(); i++)
+    for(int i = 0; i < m_players.length(); ++i)
     {
         if(m_players[i]->isAlive())
         {
@@ -678,16 +673,16 @@ void Game::setRoundFinished()
     {
         m_players[nIndex]->addPoint();
     }
-    
+
     pause(true);
-    
-    for(int i = 0; i < m_players.length(); i++)
+
+    for(auto & player : m_players)
     {
         // check if a player reaches the win points
-        if (m_players[i]->points() >= m_winPoints)
+        if (player->points() >= m_winPoints)
         {
             m_gameOver = true;
-            m_strWinner = m_players[i]->getPlayerName();
+            m_strWinner = player->getPlayerName();
             break;
         }
     }
@@ -713,12 +708,12 @@ void Game::createBomb(Player* player, qreal x, qreal y, bool newBomb, int throwD
             return;
         }
     }
-    
+
     if(!newBomb)
     {
         return;
     }
-    
+
     m_bombCount++;
     Bomb* bomb = new Bomb((col + 0.5) * Granatier::CellSize, (row + 0.5) * Granatier::CellSize, m_arena, m_bombCount, 2500);    // time in ms
     bomb->setBombPower(player->getBombPower());
@@ -727,7 +722,7 @@ void Game::createBomb(Player* player, qreal x, qreal y, bool newBomb, int throwD
     connect(bomb, &Bomb::releaseBombArmory, player, &Player::slot_refillBombArmory);
     m_bombs.append(bomb);
     player->decrementBombArmory();
-    
+
     if(m_soundEnabled)
     {
         m_soundPutBomb->start();
